==> zio-aws-sagemakeredge_2.12-5.19.31.5-sources.jar: zio/aws/sagemakeredge/SagemakerEdge.scala <==
package zio.aws.sagemakeredge
import software.amazon.awssdk.services.sagemakeredge.model.{
  GetDeviceRegistrationRequest,
  GetDeviceRegistrationResponse,
  GetDeploymentsResponse,
  GetDeploymentsRequest,
  SendHeartbeatRequest,
  SendHeartbeatResponse
}
import software.amazon.awssdk.services.sagemakeredge.{
  SagemakerEdgeAsyncClientBuilder,
  SagemakerEdgeAsyncClient
}
import zio.aws.core.config.AwsConfig
import zio.aws.sagemakeredge.model.GetDeploymentsResponse.ReadOnly
import zio.aws.core.{AwsServiceBase, AwsError}
import zio.aws.core.aspects.{AwsCallAspect, AspectSupport}
import zio.{ZEnvironment, IO, ZIO, ZLayer, Scope}
import scala.jdk.CollectionConverters._
trait SagemakerEdge extends AspectSupport[SagemakerEdge] {
  val api: SagemakerEdgeAsyncClient
  def getDeployments(
      request: zio.aws.sagemakeredge.model.GetDeploymentsRequest
  ): IO[AwsError, ReadOnly]
  def getDeviceRegistration(
      request: zio.aws.sagemakeredge.model.GetDeviceRegistrationRequest
  ): IO[
    AwsError,
    zio.aws.sagemakeredge.model.GetDeviceRegistrationResponse.ReadOnly
  ]
  def sendHeartbeat(
      request: zio.aws.sagemakeredge.model.SendHeartbeatRequest
  ): IO[AwsError, Unit]
}
object SagemakerEdge {
  val live: ZLayer[AwsConfig, java.lang.Throwable, SagemakerEdge] = customized(
    identity
  )
  def customized(
      customization: SagemakerEdgeAsyncClientBuilder => SagemakerEdgeAsyncClientBuilder
  ): ZLayer[AwsConfig, java.lang.Throwable, SagemakerEdge] =
    ZLayer.scoped(scoped(customization))
  def scoped(
      customization: SagemakerEdgeAsyncClientBuilder => SagemakerEdgeAsyncClientBuilder
  ): ZIO[AwsConfig with Scope, java.lang.Throwable, SagemakerEdge] = for (
    awsConfig <- ZIO.service[AwsConfig]; executor <- ZIO.executor;
    builder = SagemakerEdgeAsyncClient
      .builder()
      .asyncConfiguration(
        software.amazon.awssdk.core.client.config.ClientAsyncConfiguration
          .builder()
          .advancedOption(
            software.amazon.awssdk.core.client.config.SdkAdvancedAsyncClientOption.FUTURE_COMPLETION_EXECUTOR,
            executor.asJava
          )
          .build()
      );
    b0 <- awsConfig
      .configure[SagemakerEdgeAsyncClient, SagemakerEdgeAsyncClientBuilder](
        builder
      );
    b1 <- awsConfig.configureHttpClient[
      SagemakerEdgeAsyncClient,
      SagemakerEdgeAsyncClientBuilder
    ](
      b0,
      zio.aws.core.httpclient.ServiceHttpCapabilities(supportsHttp2 = false)
    ); client <- ZIO.attempt(customization(b1).build())
  )
    yield new SagemakerEdgeImpl(
      client,
      AwsCallAspect.identity,
      ZEnvironment.empty
    )
  private class SagemakerEdgeImpl[R](
      override val api: SagemakerEdgeAsyncClient,
      override val aspect: AwsCallAspect[R],
      r: ZEnvironment[R]
  ) extends SagemakerEdge
      with AwsServiceBase[R] {
    override val serviceName: String = "SagemakerEdge"
    override def withAspect[R1](
        newAspect: AwsCallAspect[R1],
        r: ZEnvironment[R1]
    ): SagemakerEdgeImpl[R1] = new SagemakerEdgeImpl(api, newAspect, r)
    def getDeployments(
        request: zio.aws.sagemakeredge.model.GetDeploymentsRequest
    ): IO[AwsError, ReadOnly] =
      asyncRequestResponse[GetDeploymentsRequest, GetDeploymentsResponse](
        "getDeployments",
        api.getDeployments
      )(request.buildAwsValue())
        .map(zio.aws.sagemakeredge.model.GetDeploymentsResponse.wrap)
        .provideEnvironment(r)
    def getDeviceRegistration(
        request: zio.aws.sagemakeredge.model.GetDeviceRegistrationRequest
    ): IO[
      AwsError,
      zio.aws.sagemakeredge.model.GetDeviceRegistrationResponse.ReadOnly
    ] = asyncRequestResponse[
      GetDeviceRegistrationRequest,
      GetDeviceRegistrationResponse
    ]("getDeviceRegistration", api.getDeviceRegistration)(
      request.buildAwsValue()
    ).map(zio.aws.sagemakeredge.model.GetDeviceRegistrationResponse.wrap)
      .provideEnvironment(r)
    def sendHeartbeat(
        request: zio.aws.sagemakeredge.model.SendHeartbeatRequest
    ): IO[AwsError, Unit] =
      asyncRequestResponse[SendHeartbeatRequest, SendHeartbeatResponse](
        "sendHeartbeat",
        api.sendHeartbeat
      )(request.buildAwsValue()).unit.provideEnvironment(r)
  }
  def getDeployments(
      request: zio.aws.sagemakeredge.model.GetDeploymentsRequest
  ): ZIO[zio.aws.sagemakeredge.SagemakerEdge, AwsError, ReadOnly] =
    ZIO.serviceWithZIO(_.getDeployments(request))
  def getDeviceRegistration(
      request: zio.aws.sagemakeredge.model.GetDeviceRegistrationRequest
  ): ZIO[
    zio.aws.sagemakeredge.SagemakerEdge,
    AwsError,
    zio.aws.sagemakeredge.model.GetDeviceRegistrationResponse.ReadOnly
  ] = ZIO.serviceWithZIO(_.getDeviceRegistration(request))
  def sendHeartbeat(
      request: zio.aws.sagemakeredge.model.SendHeartbeatRequest
  ): ZIO[zio.aws.sagemakeredge.SagemakerEdge, AwsError, Unit] =
    ZIO.serviceWithZIO(_.sendHeartbeat(request))
}

==> zio-aws-sagemakeredge_3-5.17.147.1-sources.jar: zio/aws/sagemakeredge/SagemakerEdge.scala <==
package zio.aws.sagemakeredge
import software.amazon.awssdk.services.sagemakeredge.model.{
  SendHeartbeatResponse,
  SendHeartbeatRequest,
  GetDeviceRegistrationResponse,
  GetDeviceRegistrationRequest
}
import software.amazon.awssdk.services.sagemakeredge.{
  SagemakerEdgeAsyncClientBuilder,
  SagemakerEdgeAsyncClient
}
import zio.aws.core.config.AwsConfig
import zio.aws.sagemakeredge.model.GetDeviceRegistrationResponse.ReadOnly
import zio.aws.core.{AwsServiceBase, AwsError}
import zio.aws.core.aspects.{AwsCallAspect, AspectSupport}
import zio.{ZEnvironment, ZManaged, IO, ZIO, ZLayer}
import scala.jdk.CollectionConverters.*
trait SagemakerEdge extends AspectSupport[SagemakerEdge] {
  val api: SagemakerEdgeAsyncClient
  def getDeviceRegistration(
      request: zio.aws.sagemakeredge.model.GetDeviceRegistrationRequest
  ): IO[AwsError, ReadOnly]
  def sendHeartbeat(
      request: zio.aws.sagemakeredge.model.SendHeartbeatRequest
  ): IO[AwsError, Unit]
}
object SagemakerEdge {
  val live: ZLayer[AwsConfig, java.lang.Throwable, SagemakerEdge] = customized(
    identity
  )
  def customized(
      customization: SagemakerEdgeAsyncClientBuilder => SagemakerEdgeAsyncClientBuilder
  ): ZLayer[AwsConfig, java.lang.Throwable, SagemakerEdge] = managed(
    customization
  ).toLayer
  def managed(
      customization: SagemakerEdgeAsyncClientBuilder => SagemakerEdgeAsyncClientBuilder
  ): ZManaged[AwsConfig, java.lang.Throwable, SagemakerEdge] = for (
    awsConfig <- ZManaged.service[AwsConfig];
    executor <- ZIO.executor.toManaged;
    builder = SagemakerEdgeAsyncClient
      .builder()
      .asyncConfiguration(
        software.amazon.awssdk.core.client.config.ClientAsyncConfiguration
          .builder()
          .advancedOption(
            software.amazon.awssdk.core.client.config.SdkAdvancedAsyncClientOption.FUTURE_COMPLETION_EXECUTOR,
            executor.asJava
          )
          .build()
      );
    b0 <- awsConfig
      .configure[SagemakerEdgeAsyncClient, SagemakerEdgeAsyncClientBuilder](
        builder
      )
      .toManaged;
    b1 <- awsConfig
      .configureHttpClient[
        SagemakerEdgeAsyncClient,
        SagemakerEdgeAsyncClientBuilder
      ](
        b0,
        zio.aws.core.httpclient.ServiceHttpCapabilities(supportsHttp2 = false)
      )
      .toManaged; client <- zio.ZIO(customization(b1).build()).toManaged
  )
    yield new SagemakerEdgeImpl(
      client,
      AwsCallAspect.identity,
      ZEnvironment.empty
    )
  private class SagemakerEdgeImpl[R](
      override val api: SagemakerEdgeAsyncClient,
      override val aspect: AwsCallAspect[R],
      r: ZEnvironment[R]
  ) extends SagemakerEdge
      with AwsServiceBase[R] {
    override val serviceName: String = "SagemakerEdge"
    override def withAspect[R1](
        newAspect: AwsCallAspect[R1],
        r: ZEnvironment[R1]
    ): SagemakerEdgeImpl[R1] = new SagemakerEdgeImpl(api, newAspect, r)
    def getDeviceRegistration(
        request: zio.aws.sagemakeredge.model.GetDeviceRegistrationRequest
    ): IO[AwsError, ReadOnly] = asyncRequestResponse[
      GetDeviceRegistrationRequest,
      GetDeviceRegistrationResponse
    ]("getDeviceRegistration", api.getDeviceRegistration)(
      request.buildAwsValue()
    ).map(zio.aws.sagemakeredge.model.GetDeviceRegistrationResponse.wrap)
      .provideEnvironment(r)
    def sendHeartbeat(
        request: zio.aws.sagemakeredge.model.SendHeartbeatRequest
    ): IO[AwsError, Unit] =
      asyncRequestResponse[SendHeartbeatRequest, SendHeartbeatResponse](
        "sendHeartbeat",
        api.sendHeartbeat
      )(request.buildAwsValue()).unit.provideEnvironment(r)
  }
  def getDeviceRegistration(
      request: zio.aws.sagemakeredge.model.GetDeviceRegistrationRequest
  ): ZIO[zio.aws.sagemakeredge.SagemakerEdge, AwsError, ReadOnly] =
    ZIO.serviceWithZIO(_.getDeviceRegistration(request))
  def sendHeartbeat(
      request: zio.aws.sagemakeredge.model.SendHeartbeatRequest
  ): ZIO[zio.aws.sagemakeredge.SagemakerEdge, AwsError, Unit] =
    ZIO.serviceWithZIO(_.sendHeartbeat(request))
}
